(v1.1.0)=
### 1.1.0 {small}`2018-06-01`

- {func}`~scanpy.set_figure_params` by default passes `vector_friendly=True` and allows you to produce reasonablly sized pdfs by rasterizing large scatter plots {smaller}`A Wolf`
- {func}`~scanpy.tl.draw_graph` defaults to the ForceAtlas2 layout {cite:p}`Jacomy2014,Chippada2018`, which is often more visually appealing and whose computation is much faster {smaller}`S Wollock`
- {func}`~scanpy.pl.scatter` also plots along variables axis {smaller}`MD Luecken`
- {func}`~scanpy.pp.pca` and {func}`~scanpy.pp.log1p` support chunk processing {smaller}`S Rybakov`
- {func}`~scanpy.pp.regress_out` is back to multiprocessing {smaller}`F Ramirez`
- {func}`~scanpy.read` reads compressed text files {smaller}`G Eraslan`
- {func}`~scanpy.queries.mitochondrial_genes` for querying mito genes {smaller}`FG Brundu`
- {func}`~scanpy.external.pp.mnn_correct` for batch correction {cite:p}`Haghverdi2018,Kang2018`
- {func}`~scanpy.external.tl.phate` for low-dimensional embedding {cite:p}`Moon2019` {smaller}`S Gigante`
- {func}`~scanpy.external.tl.sandbag`, {func}`~scanpy.external.tl.cyclone` for scoring genes {cite:p}`Scialdone2015,Fechtner2018`
